# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetNodeDevicesResult',
    'AwaitableGetNodeDevicesResult',
    'get_node_devices',
    'get_node_devices_output',
]

@pulumi.output_type
class GetNodeDevicesResult:
    """
    A collection of values returned by getNodeDevices.
    """
    def __init__(__self__, capability=None, devices=None, id=None):
        if capability and not isinstance(capability, str):
            raise TypeError("Expected argument 'capability' to be a str")
        pulumi.set(__self__, "capability", capability)
        if devices and not isinstance(devices, list):
            raise TypeError("Expected argument 'devices' to be a list")
        pulumi.set(__self__, "devices", devices)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter
    def capability(self) -> Optional[str]:
        return pulumi.get(self, "capability")

    @property
    @pulumi.getter
    def devices(self) -> Sequence[str]:
        """
        A list of devices that match the selected capability
        """
        return pulumi.get(self, "devices")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetNodeDevicesResult(GetNodeDevicesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodeDevicesResult(
            capability=self.capability,
            devices=self.devices,
            id=self.id)


def get_node_devices(capability: Optional[str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodeDevicesResult:
    """
    Retrieve information about the devices present on the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    node = libvirt.get_node_devices(capability="pci")
    ```


    :param str capability: The type of device, used to filter the output by capability type.
           Can be one of `system`, `pci`, `usb_device`,  `usb`,  `net`,  `scsi_host`,
           `scsi_target`,  `scsi`,  `storage`, `fc_host`,  `vports`, `scsi_generic`, `drm`,
           `mdev`, `mdev_types`, `ccw`, `css`, `ap_card`, `ap_queue`, `ap_matrix`.
           Defaults to all active devices.
    """
    __args__ = dict()
    __args__['capability'] = capability
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('libvirt:index/getNodeDevices:getNodeDevices', __args__, opts=opts, typ=GetNodeDevicesResult).value

    return AwaitableGetNodeDevicesResult(
        capability=pulumi.get(__ret__, 'capability'),
        devices=pulumi.get(__ret__, 'devices'),
        id=pulumi.get(__ret__, 'id'))


@_utilities.lift_output_func(get_node_devices)
def get_node_devices_output(capability: Optional[pulumi.Input[Optional[str]]] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNodeDevicesResult]:
    """
    Retrieve information about the devices present on the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    node = libvirt.get_node_devices(capability="pci")
    ```


    :param str capability: The type of device, used to filter the output by capability type.
           Can be one of `system`, `pci`, `usb_device`,  `usb`,  `net`,  `scsi_host`,
           `scsi_target`,  `scsi`,  `storage`, `fc_host`,  `vports`, `scsi_generic`, `drm`,
           `mdev`, `mdev_types`, `ccw`, `css`, `ap_card`, `ap_queue`, `ap_matrix`.
           Defaults to all active devices.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetNodeDeviceInfoResult',
    'AwaitableGetNodeDeviceInfoResult',
    'get_node_device_info',
    'get_node_device_info_output',
]

@pulumi.output_type
class GetNodeDeviceInfoResult:
    """
    A collection of values returned by getNodeDeviceInfo.
    """
    def __init__(__self__, capability=None, devnodes=None, id=None, name=None, parent=None, path=None, xml=None):
        if capability and not isinstance(capability, dict):
            raise TypeError("Expected argument 'capability' to be a dict")
        pulumi.set(__self__, "capability", capability)
        if devnodes and not isinstance(devnodes, list):
            raise TypeError("Expected argument 'devnodes' to be a list")
        pulumi.set(__self__, "devnodes", devnodes)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parent and not isinstance(parent, str):
            raise TypeError("Expected argument 'parent' to be a str")
        pulumi.set(__self__, "parent", parent)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if xml and not isinstance(xml, str):
            raise TypeError("Expected argument 'xml' to be a str")
        pulumi.set(__self__, "xml", xml)

    @property
    @pulumi.getter
    def capability(self) -> 'outputs.GetNodeDeviceInfoCapabilityResult':
        """
        Holds key `type` that describes the type of network interface: `80203` for IEEE 802.3 or `80211` for IEEE 802.11
        """
        return pulumi.get(self, "capability")

    @property
    @pulumi.getter
    def devnodes(self) -> Sequence['outputs.GetNodeDeviceInfoDevnodeResult']:
        """
        For type `drm` holds the `path` and `link` that point to the device
        """
        return pulumi.get(self, "devnodes")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def parent(self) -> str:
        """
        The parent of this device in the hierarchy
        """
        return pulumi.get(self, "parent")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        Full path of the device
        """
        return pulumi.get(self, "path")

    @property
    @pulumi.getter
    def xml(self) -> str:
        """
        The XML returned by the libvirt API call
        """
        return pulumi.get(self, "xml")


class AwaitableGetNodeDeviceInfoResult(GetNodeDeviceInfoResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodeDeviceInfoResult(
            capability=self.capability,
            devnodes=self.devnodes,
            id=self.id,
            name=self.name,
            parent=self.parent,
            path=self.path,
            xml=self.xml)


def get_node_device_info(capability: Optional[Union['GetNodeDeviceInfoCapabilityArgs', 'GetNodeDeviceInfoCapabilityArgsDict']] = None,
                         name: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodeDeviceInfoResult:
    """
    Retrieve information about a specific device on the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    device = libvirt.get_node_device_info(name="pci_0000_00_00_0")
    ```


    :param Union['GetNodeDeviceInfoCapabilityArgs', 'GetNodeDeviceInfoCapabilityArgsDict'] capability: Holds key `type` that describes the type of network interface: `80203` for IEEE 802.3 or `80211` for IEEE 802.11
    :param str name: The name of the device name as expected by [libvirt](https://www.libvirt.org/manpages/virsh.html#nodedev-commands).
    """
    __args__ = dict()
    __args__['capability'] = capability
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('libvirt:index/getNodeDeviceInfo:getNodeDeviceInfo', __args__, opts=opts, typ=GetNodeDeviceInfoResult).value

    return AwaitableGetNodeDeviceInfoResult(
        capability=pulumi.get(__ret__, 'capability'),
        devnodes=pulumi.get(__ret__, 'devnodes'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        parent=pulumi.get(__ret__, 'parent'),
        path=pulumi.get(__ret__, 'path'),
        xml=pulumi.get(__ret__, 'xml'))


@_utilities.lift_output_func(get_node_device_info)
def get_node_device_info_output(capability: Optional[pulumi.Input[Optional[Union['GetNodeDeviceInfoCapabilityArgs', 'GetNodeDeviceInfoCapabilityArgsDict']]]] = None,
                                name: Optional[pulumi.Input[str]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNodeDeviceInfoResult]:
    """
    Retrieve information about a specific device on the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    device = libvirt.get_node_device_info(name="pci_0000_00_00_0")
    ```


    :param Union['GetNodeDeviceInfoCapabilityArgs', 'GetNodeDeviceInfoCapabilityArgsDict'] capability: Holds key `type` that describes the type of network interface: `80203` for IEEE 802.3 or `80211` for IEEE 802.11
    :param str name: The name of the device name as expected by [libvirt](https://www.libvirt.org/manpages/virsh.html#nodedev-commands).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from . import _utilities

__all__ = [
    'GetNodeInfoResult',
    'AwaitableGetNodeInfoResult',
    'get_node_info',
    'get_node_info_output',
]

@pulumi.output_type
class GetNodeInfoResult:
    """
    A collection of values returned by getNodeInfo.
    """
    def __init__(__self__, cpu_cores_per_socket=None, cpu_cores_total=None, cpu_model=None, cpu_sockets=None, cpu_threads_per_core=None, id=None, memory_total_kb=None, numa_nodes=None):
        if cpu_cores_per_socket and not isinstance(cpu_cores_per_socket, int):
            raise TypeError("Expected argument 'cpu_cores_per_socket' to be a int")
        pulumi.set(__self__, "cpu_cores_per_socket", cpu_cores_per_socket)
        if cpu_cores_total and not isinstance(cpu_cores_total, int):
            raise TypeError("Expected argument 'cpu_cores_total' to be a int")
        pulumi.set(__self__, "cpu_cores_total", cpu_cores_total)
        if cpu_model and not isinstance(cpu_model, str):
            raise TypeError("Expected argument 'cpu_model' to be a str")
        pulumi.set(__self__, "cpu_model", cpu_model)
        if cpu_sockets and not isinstance(cpu_sockets, int):
            raise TypeError("Expected argument 'cpu_sockets' to be a int")
        pulumi.set(__self__, "cpu_sockets", cpu_sockets)
        if cpu_threads_per_core and not isinstance(cpu_threads_per_core, int):
            raise TypeError("Expected argument 'cpu_threads_per_core' to be a int")
        pulumi.set(__self__, "cpu_threads_per_core", cpu_threads_per_core)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if memory_total_kb and not isinstance(memory_total_kb, int):
            raise TypeError("Expected argument 'memory_total_kb' to be a int")
        pulumi.set(__self__, "memory_total_kb", memory_total_kb)
        if numa_nodes and not isinstance(numa_nodes, int):
            raise TypeError("Expected argument 'numa_nodes' to be a int")
        pulumi.set(__self__, "numa_nodes", numa_nodes)

    @property
    @pulumi.getter(name="cpuCoresPerSocket")
    def cpu_cores_per_socket(self) -> int:
        """
        Number of CPU cores per each socket
        """
        return pulumi.get(self, "cpu_cores_per_socket")

    @property
    @pulumi.getter(name="cpuCoresTotal")
    def cpu_cores_total(self) -> int:
        """
        Number of CPU cores in total
        """
        return pulumi.get(self, "cpu_cores_total")

    @property
    @pulumi.getter(name="cpuModel")
    def cpu_model(self) -> str:
        """
        CPU Architecture, usually `x86_64`
        """
        return pulumi.get(self, "cpu_model")

    @property
    @pulumi.getter(name="cpuSockets")
    def cpu_sockets(self) -> int:
        """
        How many CPU sockets are present
        """
        return pulumi.get(self, "cpu_sockets")

    @property
    @pulumi.getter(name="cpuThreadsPerCore")
    def cpu_threads_per_core(self) -> int:
        """
        How many CPU Threads are available per each CPU core
        """
        return pulumi.get(self, "cpu_threads_per_core")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="memoryTotalKb")
    def memory_total_kb(self) -> int:
        """
        The amount of memory installed, in KiB
        """
        return pulumi.get(self, "memory_total_kb")

    @property
    @pulumi.getter(name="numaNodes")
    def numa_nodes(self) -> int:
        """
        How many NUMA nodes/cells are available.
        """
        return pulumi.get(self, "numa_nodes")


class AwaitableGetNodeInfoResult(GetNodeInfoResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetNodeInfoResult(
            cpu_cores_per_socket=self.cpu_cores_per_socket,
            cpu_cores_total=self.cpu_cores_total,
            cpu_model=self.cpu_model,
            cpu_sockets=self.cpu_sockets,
            cpu_threads_per_core=self.cpu_threads_per_core,
            id=self.id,
            memory_total_kb=self.memory_total_kb,
            numa_nodes=self.numa_nodes)


def get_node_info(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetNodeInfoResult:
    """
    Retrieve information about the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    node = libvirt.get_node_info()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('libvirt:index/getNodeInfo:getNodeInfo', __args__, opts=opts, typ=GetNodeInfoResult).value

    return AwaitableGetNodeInfoResult(
        cpu_cores_per_socket=pulumi.get(__ret__, 'cpu_cores_per_socket'),
        cpu_cores_total=pulumi.get(__ret__, 'cpu_cores_total'),
        cpu_model=pulumi.get(__ret__, 'cpu_model'),
        cpu_sockets=pulumi.get(__ret__, 'cpu_sockets'),
        cpu_threads_per_core=pulumi.get(__ret__, 'cpu_threads_per_core'),
        id=pulumi.get(__ret__, 'id'),
        memory_total_kb=pulumi.get(__ret__, 'memory_total_kb'),
        numa_nodes=pulumi.get(__ret__, 'numa_nodes'))


@_utilities.lift_output_func(get_node_info)
def get_node_info_output(opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetNodeInfoResult]:
    """
    Retrieve information about the current node

    ## Example Usage

    ```python
    import pulumi
    import pulumi_libvirt as libvirt

    node = libvirt.get_node_info()
    ```
    """
    ...
